---
title: <span class="badge object-type-scalar"></span> Roentgen
---
# <span class="badge object-type-scalar"></span> Roentgen

Radiation: roentgen (R)

## Definition

```python
# Radiation: roentgen (R)
Roentgen: typing.Literal["radr"] = "radr"
```
